==> 2.1.0.tar.gz: lib/src/models/video_player_configuration.dart <==
import 'video_player_complete_action.dart';
import 'video_player_cta_delay.dart';
import 'video_player_cta_style.dart';
import 'video_player_cta_width.dart';
import 'video_player_style.dart';

class VideoPlayerConfiguration {
  /// Sets the proportion of the video player to its container.
  /// Defaults to full.
  VideoPlayerStyle? playerStyle;

  /// Behavior occurring after video is complete.
  /// Defaults to advanceToNext.
  VideoPlayerCompleteAction? videoCompleteAction;

  /// Indicates if the video player shows share button.
  /// Defaults to true.
  bool? showShareButton;

  /// The style of CTA button style. Only supported on iOS.
  VideoPlayerCTAStyle? ctaButtonStyle;

  /// Indicates if the video player shows playback button.
  /// Defaults to false on iOS. Default to true on Android.
  bool? showPlaybackButton;

  /// Indicates if the video player shows mute button.
  /// Defaults to true.
  bool? showMuteButton;

  /// Indicates if Firework branding should be showed or not.
  /// Defaults to true.
  bool? showBranding;

  /// Specifies the delay before showing the CTA.
  /// Defaults to { type: constant, value: 3 }.
  VideoPlayerCTADelay? ctaDelay;

  /// Specifies the delay before the highlight animation occurs.
  /// Defaults to { type: constant, value: 2 }.
  VideoPlayerCTADelay? ctaHighlightDelay;

  /// The share base URL of the video.
  String? shareBaseURL;

  /// Specifies the desired width for the Video Player CTA button.
  /// Defaults to fullWidth.
  VideoPlayerCTAWidth? ctaWidth;

  VideoPlayerConfiguration({
    this.playerStyle,
    this.videoCompleteAction,
    this.showShareButton,
    this.ctaButtonStyle,
    this.showPlaybackButton,
    this.showMuteButton,
    this.showBranding,
    this.ctaDelay,
    this.ctaHighlightDelay,
    this.shareBaseURL,
    this.ctaWidth,
  });

  @override
  bool operator ==(Object other) {
    if (identical(this, other)) {
      return true;
    }

    if (other is VideoPlayerConfiguration) {
      return playerStyle == other.playerStyle &&
          videoCompleteAction == other.videoCompleteAction &&
          showShareButton == other.showShareButton &&
          ctaButtonStyle == other.ctaButtonStyle &&
          showPlaybackButton == other.showPlaybackButton &&
          showMuteButton == other.showMuteButton &&
          showBranding == other.showBranding &&
          ctaDelay == other.ctaDelay &&
          ctaHighlightDelay == other.ctaHighlightDelay &&
          shareBaseURL == other.shareBaseURL &&
          ctaWidth == other.ctaWidth;
    }

    return false;
  }

  @override
  int get hashCode =>
      playerStyle.hashCode ^
      videoCompleteAction.hashCode ^
      showShareButton.hashCode ^
      ctaButtonStyle.hashCode ^
      showPlaybackButton.hashCode ^
      showMuteButton.hashCode ^
      showBranding.hashCode ^
      ctaDelay.hashCode ^
      ctaHighlightDelay.hashCode ^
      shareBaseURL.hashCode ^
      ctaWidth.hashCode;

  VideoPlayerConfiguration deepCopy() => VideoPlayerConfiguration(
        playerStyle: playerStyle,
        videoCompleteAction: videoCompleteAction,
        showShareButton: showShareButton,
        ctaButtonStyle: ctaButtonStyle?.deepCopy(),
        showPlaybackButton: showPlaybackButton,
        showMuteButton: showMuteButton,
        showBranding: showBranding,
        ctaDelay: ctaDelay?.deepCopy(),
        ctaHighlightDelay: ctaHighlightDelay?.deepCopy(),
        shareBaseURL: shareBaseURL,
        ctaWidth: ctaWidth,
      );
}

==> 2.4.6.tar.gz: lib/src/models/video_player_configuration.dart <==
import 'video_player_button_configuration.dart';
import 'video_player_complete_action.dart';
import 'video_player_cta_delay.dart';
import 'video_player_cta_style.dart';
import 'video_player_cta_width.dart';
import 'video_player_logo_configuration.dart';
import 'video_player_style.dart';

class VideoPlayerConfiguration {
  /// Sets the proportion of the video player to its container.
  /// Defaults to full.
  VideoPlayerStyle? playerStyle;

  /// Behavior occurring after video is complete.
  /// Defaults to advanceToNext.
  VideoPlayerCompleteAction? videoCompleteAction;

  /// Indicates if the video player shows share button.
  /// Defaults to true.
  bool? showShareButton;

  /// The style of CTA button style. Only supported on iOS.
  VideoPlayerCTAStyle? ctaButtonStyle;

  /// Indicates if the video player shows playback button.
  /// Defaults to false on iOS. Default to true on Android.
  bool? showPlaybackButton;

  /// Indicates if the video player shows mute button.
  /// Defaults to true.
  bool? showMuteButton;

  /// Indicates if Firework branding should be showed or not.
  /// Defaults to true.
  bool? showBranding;

  /// Specifies the delay before showing the CTA.
  /// Defaults to { type: constant, value: 3 }.
  VideoPlayerCTADelay? ctaDelay;

  /// Specifies the delay before the highlight animation occurs.
  /// Defaults to { type: constant, value: 2 }.
  VideoPlayerCTADelay? ctaHighlightDelay;

  /// The share base URL of the video.
  String? shareBaseURL;

  /// Specifies the desired width for the Video Player CTA button.
  /// Defaults to fullWidth.
  VideoPlayerCTAWidth? ctaWidth;

  /// The host app could use this property to customize the button images of the video player.
  VideoPlayerButtonConfiguration? buttonConfiguration;

  /// Specifies the logo configuration
  /// Defaults to { option: 'disabled' }
  /// Only supported on iOS.
  VideoPlayerLogoConfiguration? videoPlayerLogoConfiguration;

  /// Specifies if the video detail title should be showed or not.
  bool? showVideoDetailTitle;

  VideoPlayerConfiguration({
    this.playerStyle,
    this.videoCompleteAction,
    this.showShareButton,
    this.ctaButtonStyle,
    this.showPlaybackButton,
    this.showMuteButton,
    this.showBranding,
    this.ctaDelay,
    this.ctaHighlightDelay,
    this.shareBaseURL,
    this.ctaWidth,
    this.buttonConfiguration,
    this.videoPlayerLogoConfiguration,
    this.showVideoDetailTitle,
  });

  @override
  bool operator ==(Object other) {
    if (identical(this, other)) {
      return true;
    }

    if (other is VideoPlayerConfiguration) {
      return playerStyle == other.playerStyle &&
          videoCompleteAction == other.videoCompleteAction &&
          showShareButton == other.showShareButton &&
          ctaButtonStyle == other.ctaButtonStyle &&
          showPlaybackButton == other.showPlaybackButton &&
          showMuteButton == other.showMuteButton &&
          showBranding == other.showBranding &&
          ctaDelay == other.ctaDelay &&
          ctaHighlightDelay == other.ctaHighlightDelay &&
          shareBaseURL == other.shareBaseURL &&
          ctaWidth == other.ctaWidth &&
          buttonConfiguration == other.buttonConfiguration &&
          videoPlayerLogoConfiguration == other.videoPlayerLogoConfiguration &&
          showVideoDetailTitle == other.showVideoDetailTitle;
    }

    return false;
  }

  @override
  int get hashCode =>
      playerStyle.hashCode ^
      videoCompleteAction.hashCode ^
      showShareButton.hashCode ^
      ctaButtonStyle.hashCode ^
      showPlaybackButton.hashCode ^
      showMuteButton.hashCode ^
      showBranding.hashCode ^
      ctaDelay.hashCode ^
      ctaHighlightDelay.hashCode ^
      shareBaseURL.hashCode ^
      ctaWidth.hashCode ^
      buttonConfiguration.hashCode ^
      videoPlayerLogoConfiguration.hashCode ^
      showVideoDetailTitle.hashCode;

  VideoPlayerConfiguration deepCopy() => VideoPlayerConfiguration(
        playerStyle: playerStyle,
        videoCompleteAction: videoCompleteAction,
        showShareButton: showShareButton,
        ctaButtonStyle: ctaButtonStyle?.deepCopy(),
        showPlaybackButton: showPlaybackButton,
        showMuteButton: showMuteButton,
        showBranding: showBranding,
        ctaDelay: ctaDelay?.deepCopy(),
        ctaHighlightDelay: ctaHighlightDelay?.deepCopy(),
        shareBaseURL: shareBaseURL,
        ctaWidth: ctaWidth,
        buttonConfiguration: buttonConfiguration?.deepCopy(),
        videoPlayerLogoConfiguration: videoPlayerLogoConfiguration?.deepCopy(),
        showVideoDetailTitle: showVideoDetailTitle,
      );
}
